#!/bin/sh
terminate () {
    echo "Terminate signal received, attempting a graceful shutdown process $workerPid"
    kill -12 ${workerPid} # Worker service is listening to SIGUSR2 for graceful shutdown, see the main.ts file.
    wait ${workerPid}
    echo "Process $workerPid terminated"
}

compute_max_old_space_size() {
    local percent_retained=$1
    local max_memory
    if [ -f /sys/fs/cgroup/memory/memory.limit_in_bytes ]; then
        max_memory=$(cat /sys/fs/cgroup/memory/memory.limit_in_bytes)
    elif [ -f /sys/fs/cgroup/memory.max ]; then
        max_memory=$(cat /sys/fs/cgroup/memory.max)
    else
        max_memory=$((512 * 1024 * 1024))
    fi
    local megabyte=$(( 1024*1024 ))
    local max_memory_mb=$(( max_memory / megabyte ))
    echo "$(( max_memory_mb * percent_retained / 100 ))"
}

if [ -z "$PREDEFINED_MAX_OLD_SPACE_SIZE" ]; then
    echo "PREDEFINED_MAX_OLD_SPACE_SIZE is not set, computing max old space size based on memory limit"
    MAX_OLD_SPACE_SIZE=$(compute_max_old_space_size 50)
else
    echo "MAX_OLD_SPACE_SIZE is set to $PREDEFINED_MAX_OLD_SPACE_SIZE"
    MAX_OLD_SPACE_SIZE=$PREDEFINED_MAX_OLD_SPACE_SIZE
fi
echo "MAX_OLD_SPACE_SIZE is $MAX_OLD_SPACE_SIZE Mo"
trap terminate INT TERM HUP

exec "node" "--no-node-snapshot" "--max-old-space-size=$MAX_OLD_SPACE_SIZE" "dist/main" &
workerPid=$!

wait ${workerPid}
